from . import _version
from prefect_kubernetes.credentials import KubernetesCredentials  # noqa F401
from prefect_kubernetes.flows import run_namespaced_job  # noqa F401
from prefect_kubernetes.jobs import KubernetesJob  # noqa F401


__version__ = _version.get_versions()["version"]
